translate.convert.txt2po

Package translate :: Package convert :: Module txt2po |
[hide private]
[frames] | no frames]

# Module txt2po

source code

convert plain text (.txt) files to Gettext PO localization files

See: http://translate.sourceforge.net/wiki/toolkit/txt2po for examples and usage instructions

Classes | [hide private]
| txt2po

Functions | [hide private]
converttxt(inputfile, outputfile, templates, duplicatestyle="msgctxt", encoding="utf-8", flavour=None) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: txt, po